==> benchmark-api-1.9.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/dsbenchmark/rev150105/TestStatusBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.dsbenchmark.rev150105;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.Uint32;

/**
 * Class that builds {@link TestStatusBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     TestStatusBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new TestStatusBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of TestStatusBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see TestStatusBuilder
 * @see Builder
 *
 */
public class TestStatusBuilder implements Builder<TestStatus> {

    private TestStatus.ExecStatus _execStatus;
    private Uint32 _testsCompleted;


    Map<Class<? extends Augmentation<TestStatus>>, Augmentation<TestStatus>> augmentation = Collections.emptyMap();

    public TestStatusBuilder() {
    }

    public TestStatusBuilder(TestStatus base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<TestStatus>>, Augmentation<TestStatus>> aug =((AugmentationHolder<TestStatus>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._execStatus = base.getExecStatus();
        this._testsCompleted = base.getTestsCompleted();
    }


    public TestStatus.ExecStatus getExecStatus() {
        return _execStatus;
    }
    
    public Uint32 getTestsCompleted() {
        return _testsCompleted;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<TestStatus>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public TestStatusBuilder setExecStatus(final TestStatus.ExecStatus value) {
        this._execStatus = value;
        return this;
    }
    
    public TestStatusBuilder setTestsCompleted(final Uint32 value) {
        this._testsCompleted = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setTestsCompleted(Uint32)} instead.
     */
    @Deprecated(forRemoval = true)
    public TestStatusBuilder setTestsCompleted(final Long value) {
        return setTestsCompleted(CodeHelpers.compatUint(value));
    }
    
    public TestStatusBuilder addAugmentation(Class<? extends Augmentation<TestStatus>> augmentationType, Augmentation<TestStatus> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public TestStatusBuilder removeAugmentation(Class<? extends Augmentation<TestStatus>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public TestStatus build() {
        return new TestStatusImpl(this);
    }

    private static final class TestStatusImpl
        extends AbstractAugmentable<TestStatus>
        implements TestStatus {
    
        private final TestStatus.ExecStatus _execStatus;
        private final Uint32 _testsCompleted;
    
        TestStatusImpl(TestStatusBuilder base) {
            super(base.augmentation);
            this._execStatus = base.getExecStatus();
            this._testsCompleted = base.getTestsCompleted();
        }
    
        @Override
        public TestStatus.ExecStatus getExecStatus() {
            return _execStatus;
        }
        
        @Override
        public Uint32 getTestsCompleted() {
            return _testsCompleted;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_execStatus);
            result = prime * result + Objects.hashCode(_testsCompleted);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!TestStatus.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            TestStatus other = (TestStatus)obj;
            if (!Objects.equals(_execStatus, other.getExecStatus())) {
                return false;
            }
            if (!Objects.equals(_testsCompleted, other.getTestsCompleted())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                TestStatusImpl otherImpl = (TestStatusImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<TestStatus>>, Augmentation<TestStatus>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("TestStatus");
            CodeHelpers.appendValue(helper, "_execStatus", _execStatus);
            CodeHelpers.appendValue(helper, "_testsCompleted", _testsCompleted);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> benchmark-api-2.0.5-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/dsbenchmark/rev150105/TestStatusBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.dsbenchmark.rev150105;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Deprecated;
import java.lang.Long;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.Uint32;

/**
 * Class that builds {@link TestStatusBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     TestStatusBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new TestStatusBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of TestStatusBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see TestStatusBuilder
 * @see Builder
 *
 */
public class TestStatusBuilder implements Builder<TestStatus> {

    private TestStatus.ExecStatus _execStatus;
    private Uint32 _testsCompleted;


    Map<Class<? extends Augmentation<TestStatus>>, Augmentation<TestStatus>> augmentation = Collections.emptyMap();

    public TestStatusBuilder() {
    }

    public TestStatusBuilder(TestStatus base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<TestStatus>>, Augmentation<TestStatus>> aug =((AugmentationHolder<TestStatus>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._execStatus = base.getExecStatus();
        this._testsCompleted = base.getTestsCompleted();
    }


    public TestStatus.ExecStatus getExecStatus() {
        return _execStatus;
    }
    
    public Uint32 getTestsCompleted() {
        return _testsCompleted;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<TestStatus>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    public TestStatusBuilder setExecStatus(final TestStatus.ExecStatus value) {
        this._execStatus = value;
        return this;
    }
    
    public TestStatusBuilder setTestsCompleted(final Uint32 value) {
        this._testsCompleted = value;
        return this;
    }
    
    /**
     * Utility migration setter.
     *
     * @param value field value in legacy type
     * @return this builder
     * @deprecated Use {#link setTestsCompleted(Uint32)} instead.
     */
    @Deprecated(forRemoval = true)
    public TestStatusBuilder setTestsCompleted(final Long value) {
        return setTestsCompleted(CodeHelpers.compatUint(value));
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public TestStatusBuilder addAugmentation(Augmentation<TestStatus> augmentation) {
        return doAddAugmentation(augmentation.implementedInterface(), augmentation);
    }
    
    /**
      * Add or remove an augmentation to this builder's product.
      *
      * @param augmentationType augmentation type to be added or removed
      * @param augmentationValue augmentation value, null if the augmentation type should be removed
      * @return this builder
      * @deprecated Use either {@link #addAugmentation(Augmentation)} or {@link #removeAugmentation(Class)} instead.
      */
    @Deprecated(forRemoval = true)
    public TestStatusBuilder addAugmentation(Class<? extends Augmentation<TestStatus>> augmentationType, Augmentation<TestStatus> augmentationValue) {
        return augmentationValue == null ? removeAugmentation(augmentationType) : doAddAugmentation(augmentationType, augmentationValue);
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public TestStatusBuilder removeAugmentation(Class<? extends Augmentation<TestStatus>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }
    
    private TestStatusBuilder doAddAugmentation(Class<? extends Augmentation<TestStatus>> augmentationType, Augmentation<TestStatus> augmentationValue) {
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }

    @Override
    public TestStatus build() {
        return new TestStatusImpl(this);
    }

    private static final class TestStatusImpl
        extends AbstractAugmentable<TestStatus>
        implements TestStatus {
    
        private final TestStatus.ExecStatus _execStatus;
        private final Uint32 _testsCompleted;
    
        TestStatusImpl(TestStatusBuilder base) {
            super(base.augmentation);
            this._execStatus = base.getExecStatus();
            this._testsCompleted = base.getTestsCompleted();
        }
    
        @Override
        public TestStatus.ExecStatus getExecStatus() {
            return _execStatus;
        }
        
        @Override
        public Uint32 getTestsCompleted() {
            return _testsCompleted;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_execStatus);
            result = prime * result + Objects.hashCode(_testsCompleted);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!TestStatus.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            TestStatus other = (TestStatus)obj;
            if (!Objects.equals(_execStatus, other.getExecStatus())) {
                return false;
            }
            if (!Objects.equals(_testsCompleted, other.getTestsCompleted())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                TestStatusImpl otherImpl = (TestStatusImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<TestStatus>>, Augmentation<TestStatus>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("TestStatus");
            CodeHelpers.appendValue(helper, "_execStatus", _execStatus);
            CodeHelpers.appendValue(helper, "_testsCompleted", _testsCompleted);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
